@@ -33,9 +33,10 @@
 #  define KPARTS_DEPRECATED_NO_EXPORT KPARTS_NO_EXPORT KPARTS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KPARTS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KPARTS_NO_DEPRECATED
+#    define KPARTS_NO_DEPRECATED
+#  endif
 #endif
 
-#endif
+#endif /* KPARTS_EXPORT_H */
